// java

package edu.washington.cac.calendar;

import java.util.Properties;

/**
  General 'constants' for calendar programs and applications.
  The actual values of the constants should be in a .properties file.

  @author Greg Barnes
  @version 1.0
 */
public class CalProperties
{
  /** Location of the properties file */
  private static final String PROPERTIES_FILE = 
      "/properties/calendar/main.properties";

  /** Object to hold properties */
  private static Properties properties = new Properties();

  /** Load properties file */
  static {
    try {
      properties.load(CalProperties.class.getResourceAsStream(PROPERTIES_FILE));
    } catch(Exception e) {
      e.printStackTrace();
      System.err.println("Cannot find " + PROPERTIES_FILE);
    }
  }

  /** @return the base location of log files */
  public static String logBase() 
  {
    return properties.getProperty("logBase");
  }

  /** @return whether web applications should force authenticated users
    to use https
   */
  public static boolean useHttps() 
  {
    return new Boolean(properties.getProperty("useHttps")).booleanValue();
  }

  /** @return whether web applications should allow insecure login
    by users
   */
  public static boolean allowInsecureLogin() 
  {
    return new Boolean(properties.getProperty("allowInsecureLogin")).
               booleanValue();
  }

  /**
    Is the default user assumed to be a guest?
    @return Is the default user assumed to be a guest?
   */
  public static boolean defaultIsGuest()
  {
    return new Boolean(properties.getProperty("defaultIsGuest")).booleanValue();  }

  /**
    Get the URL that explains how to configure a browser to accept cookies
    @return the URL that explains how to configure a browser to accept cookies
   */
  public static String cookiesHelpUrl()
  {
    return properties.getProperty("cookiesHelpUrl");
  }
}
