// java

package edu.washington.cac.calendar.db;

import java.util.Properties;

import edu.washington.cac.calendar.CalLogFactory;
import edu.washington.cac.calendar.data.User;

/**
  Provides access to specific db information, such as the JDBC driver used, 
  the URL to access the db, etc.

  @author Greg Barnes
  @version 3.0
 */
public class DBResources {
  /** Location of the properties file */
  private static final String PROPERTIES_FILE = 
      "/properties/calendar/db.properties";

  /** Object to hold properties */
  private static Properties properties = new Properties();

  /** Load properties file */
  static {
    try {
      properties.load(DBResources.class.getResourceAsStream(PROPERTIES_FILE));
    } catch(Exception e) {
      e.printStackTrace(new CalLogFactory().create().getPrintStream());
      new CalLogFactory().create().
          println("Cannot find " + PROPERTIES_FILE);
    }
  }

  // 'names' of db's
  /** Name to use to refer to a development database */
  public static final String DEV  = "dev";

  /** Name to use to refer to a production database */
  public static final String PROD = "prod";

  /** @return Name to use to refer to the 'default' database 
    @see #DEV
    @see #PROD
   */
  public static String defaultDb()
  {
    return 
        new Boolean(properties.getProperty("useProdAsDefault")).booleanValue() ?
        PROD : DEV;
  }

  /** 
    Get the name of the production data source 
    @return the name of the production data source 
   */
  static String prodDataSourceName()
  {
    return properties.getProperty("prodDataSourceName");
  }

  /** 
    Get the name of the test data source 
    @return the name of the test data source 
   */
  static String testDataSourceName()
  {
    return properties.getProperty("testDataSourceName");
  }

  /** @return A user used to create special entries in the database,
      such as default Locations and Sponsors that should always exist.
   */
  public static User specialCreator()
  {
    return new User(properties.getProperty("specialCreator"));
  }

  /** 
    The user used to create keywords that can be used with official
    public events.

    @return The user used to create keywords that can be used with official
    public events.
   */
  public static User officialKeywordCreator()
  {
    return new User(properties.getProperty("officialKeywordCreator"));
  }

  /** 
    The user used to create keywords that can be used with unofficial
    public events.

    @return The user used to create keywords that can be used with unofficial
    public events.
   */
  public static User unofficialKeywordCreator()
  {
    return new User(properties.getProperty("unofficialKeywordCreator"));
  }

  /** 
    The user used to create keywords for public events that can only
    be entered by public event administrators

    @return The user used to create keywords for public events that can only
    be entered by public event administrators
   */
  public static User adminKeywordCreator()
  {
    return new User(properties.getProperty("adminKeywordCreator"));
  }

  /** 
    The user used to create public entities that should not be loaded by
    default

    @return The user used to create public entities that should not be 
    loaded by default
   */
  public static User notToBeLoadedByDefaultCreator()
  {
    return new User(properties.getProperty("notToBeLoadedByDefaultCreator"));
  }
}
