package pubevents.delalerts;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.PrintWriter;
import java.sql.ResultSet;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import edu.washington.cac.calendar.db.DBResources;
import edu.washington.cac.calendar.db.Fields;
import edu.washington.cac.calendar.db.Tables;

import pubevents.AdminServlet;
import pubevents.PEDefaults;
import pubevents.PEParameter;
import pubevents.addevents.SqlStatements;
import pubevents.util.PrintErrorMessage;
import pubevents.util.PrintWebPage;

/** list alerts to select in order for later deletion.
  
  @author Leman Chung, Greg Barnes
  @version 2.1
 */
public class DelAlertsList extends AdminServlet 
{
  public void performAction(HttpServletRequest req, HttpServletResponse res)
         throws IOException {

    BufferedReader in;
    PrintWriter out;
    int eventid;
    ResultSet rs = null;
    SqlStatements sqlstmts;

    String templateFile = PEDefaults.DEL_ALERTS_LIST;
    String templateFooter = PEDefaults.FOOTER;
    String templateBackToMenu = PEDefaults.BACK_TO_ADMIN_MENU;

    out = res.getWriter();
    String error_msg = "";

        sqlstmts = new SqlStatements();
        try {
              // build sql query statement over here
            String qry_statement = "select " 
                                   + Fields.EEVENT_ID.getSelectName() + ", "
                                   + Fields.ELASTMOD.getSelectName() + ", "
                                   + Fields.ECREATED.getSelectName() + ", " 
                                   + Fields.ESTARTDATE.getSelectName() + ", " 
                                   + Fields.EENDDATE.getSelectName() + ", "
                                   + Fields.ESHORTDESC.getSelectName() + ", "
                                   + Fields.ELONGDESC.getSelectName() + ", "
                                   + Fields.ELONGDESC1.getSelectName() + " from "
                                   + Tables.EVENTS.getName() + ", "
                                   + Tables.KEYWORDS.getName() + ", "
                                   + Tables.EVENTKEYWORDS.getName() + " where "
                                   + Fields.EPUBLIC.getStmtName() + "=\'T\' and " 
                                   + Fields.EEVENT_ID.getStmtName() + "=" 
                                   + Fields.EKEVENT_ID.getStmtName() + " and " 
                                   + Fields.KWORD.getStmtName() 
                                   + "=\'Alerts\' and "
                                   + Fields.KCREATOR.getStmtName() 
                                   + "=\'" + DBResources.adminKeywordCreator() 
                                   + "\' and "
                                   + Fields.EKKEYWORD_ID.getStmtName() + "="
                                   + Fields.KKEYWORD_ID.getStmtName() 
                                   + " order by "
                                   + Fields.ESTARTDATE.getStmtName();
            rs = sqlstmts.executeQuery(qry_statement);
        } catch (Exception e) {
            e.printStackTrace(System.err);
            System.err.println(e.getMessage());
            error_msg = e.getMessage();
        }
    
        try {
          if (error_msg == "") {
             if (!rs.next()) {
                error_msg = "<b>No alerts exist in database!</b><br>";
             } else {
                new PrintWebPage(templateFile, out); // print out header
                do {
                     // print out start-end dates, title and description.
                    out.println("<tr><td><input type=\"checkbox\" name=\"" + PEParameter.EVENT_IDS + "\" value=\"" + rs.getString(Fields.EEVENT_ID.getName()) + "\"></td>");
                    out.println("<td>" + rs.getDate(Fields.ESTARTDATE.getName()) + "</td>");
                    out.println("<td>" + rs.getDate(Fields.EENDDATE.getName()) + "</td>");
                    out.println("<td>" + rs.getString(Fields.ESHORTDESC.getName()) + "</td>");
                    out.print("<td>" + Fields.getEventLongdesc(rs));
                    out.println("</td></tr>");
                } while (rs.next());
                out.println("<tr><td></td><td></td><td></td><td></td></tr>");
                out.println("<tr><td></td><td></td>");
                out.println("<td><input type=\"submit\" value=\"Submit\"></td>");
                out.println("<td><input type=\"reset\" value=\"Clear\"></td>");
                out.println("<td></td></tr>");
                out.println("</TABLE>\n</FORM>");
                new PrintWebPage(templateFooter, out);
             }
          }
        } catch (Exception e) {
            e.printStackTrace(System.err);
            System.err.println(e.getMessage());
            error_msg = e.getMessage();
        }

      sqlstmts.close();

      if (error_msg != "") {
          new PrintWebPage(PEDefaults.LOGOHEADER, out);
          new PrintErrorMessage().printError(out, error_msg);
          new PrintWebPage(templateBackToMenu, out);
      }
      out.close();
  }
} // the end.
