package pubevents.extractdata;

import java.io.BufferedReader;
import java.io.InputStreamReader;
import java.io.IOException;
import java.io.PrintWriter;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.text.SimpleDateFormat;
import java.util.Calendar;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import edu.washington.cac.calendar.CalParameter;
import edu.washington.cac.calendar.MyCalendar;
import edu.washington.cac.calendar.db.DBResources;
import edu.washington.cac.calendar.db.Fields;
import edu.washington.cac.calendar.db.PubEventsQueries;
import edu.washington.cac.calendar.db.Tables;

import pubevents.NotAdminServlet;
import pubevents.PEDefaults;
import pubevents.addevents.SqlStatements;
import pubevents.util.PrintErrorMessage;
import pubevents.util.PrintWebPage;

/** List a user's events 
  
  @author Leman Chung, Greg Barnes
  @version 2.1
 */
public class ListEvents extends NotAdminServlet 
{
  String templateFile = PEDefaults.LOGOHEADER;
  /**
    Get the SQL query for this servlet
    @return the SQL query for this servlet
   */
  private static String sqlQuery(String uid)
  {
    return "select " 
           + Fields.EEVENT_ID.getSelectName() + ", " 
           + Fields.ESTARTDATE.getSelectName() + ", " 
           + Fields.EENDDATE.getSelectName() + ", "
           + Fields.ESHORTDESC.getSelectName() + ", "
           + Fields.ELONGDESC.getSelectName() + ", "
           + Fields.ELONGDESC1.getSelectName() + ", " 
           + Fields.ESTARTTIME.getSelectName() + ", "
           + Fields.EENDTIME.getSelectName() + ", " 
           + Fields.ELINK.getSelectName() + ", "
           + Fields.ECOST.getSelectName() + ", " 
           + Fields.KWORD.getSelectName() + ", " 
           + Fields.SNAME.getSelectName() + ", " 
           + Fields.SPHONE.getSelectName() + ", " 
           + Fields.SLINK.getSelectName() + ", " 
           + Fields.SEMAIL.getSelectName() + ", " 
           + Fields.LADDRESS.getSelectName() + ", " 
           + Fields.LLINK.getSelectName() + " from "
           + Tables.EVENTS.getName() + ", "
           + Tables.EVENTKEYWORDS.getName() + ", "
           + Tables.KEYWORDS.getName() + ", "
           + Tables.SPONSORS.getName() + ", "
           + Tables.LOCATIONS.getName() + " "
           + new PubEventsQueries().baseStandardWhere() + " and "
           + Fields.EEVENT_ID.getStmtName() + "=" 
           + Fields.EKEVENT_ID.getStmtName() + " and "
           + Fields.EKKEYWORD_ID.getStmtName() + "="
           + Fields.KKEYWORD_ID.getStmtName() + " and "
           + Fields.ECREATOR.getStmtName() + "=\'" 
           + uid + "\' and "
           + Fields.ESPONSOR_ID.getStmtName() + "="
           + Fields.SSPONSOR_ID.getStmtName() + " and "
           + Fields.ELOCATION_ID.getStmtName() + "="
           + Fields.LLOCATION_ID.getStmtName() 
           + " order by " 
           + Fields.ESTARTDATE.getStmtName() + " desc";
  }

  /** Do everything
    @param req Http request object
    @param res Http response object
    @exception IOException if there's a problem
   */
  public void performAction(HttpServletRequest req, HttpServletResponse res)
      throws IOException 
  {
    PrintWriter out = res.getWriter();
    String qry_statement;
    String error_msg = "";

    SqlStatements sqlstmts = new SqlStatements();
                    
    new PrintWebPage(templateFile, out);

    try {
      ResultSet rs = sqlstmts.executeQuery(sqlQuery(getUid()));

//      out.println("<br>");
//      out.println("<img SRC=\"/cal/graphics/callogo2.gif\" ALT=\"UW Calendar Logo\" BORDER=\"0\">");

      out.println("<b>Events created by " + getUid() + ":</b>");
      out.println("<br>");
      out.println("-------------------------------------------");
      out.println("<br>");

      while (rs.next()) {
        // print out events
        EventPrinter ep = new EventPrinter(out, rs);
        ep.printDates();
        ep.printCategory();
        ep.printShortdesc();
        ep.printLongdesc();
        ep.printTime();
        ep.printCost();
        ep.printLink();
        ep.printLocation();
        ep.printLocationLink();
        ep.printSponsor();
        ep.printSponsorPhone();
        ep.printSponsorLink();
        ep.printSponsorEmail();

        out.println("<form action=\"pubevents.addevents.DisplayOldEvent\" method=POST>");
        out.println("<input type=hidden name=" + CalParameter.EVENT_ID + 
                    " value=" + rs.getString(Fields.EEVENT_ID.getName()) + 
                    ">");
        out.println("<input type=submit value=\"Modify\"> this event to create a new event.<br>");
        out.println("</form>");
      }
    } catch (SQLException e) {
      e.printStackTrace(System.err);
      System.err.println("SQL Exception: " + e.getMessage());
      error_msg = "ERROR: " + e.getMessage();
    } catch (Exception e) {
      e.printStackTrace(System.err);
      System.err.println("Exception: " + e.getMessage());
      error_msg = "ERROR: " + e.getMessage();
    } finally {
      sqlstmts.close();
    }

    // print error_msg if any.
    if (error_msg != "") {
      new PrintErrorMessage().printError(out, error_msg);
    }

    new PrintWebPage(PEDefaults.FOOTER, out);
    out.close();
  }

  /**
    Print the main SQL query used by this servlet
    @param args ignored
   */
  public static void main(String[] args)
  {
    System.out.println(sqlQuery("gsbarnes"));
  }
}
