package pubevents.updtevents;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.PrintWriter;
import java.sql.ResultSet;
import java.sql.SQLException;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import edu.washington.cac.calendar.data.User;
import edu.washington.cac.calendar.db.Fields;
import edu.washington.cac.calendar.db.PubEventsQueries;

import pubevents.AdminServlet;
import pubevents.PEDefaults;
import pubevents.PEParameter;
import pubevents.addevents.SqlStatements;
import pubevents.util.PrintErrorMessage;
import pubevents.util.PrintWebPage;

/** list other people's events to update.
                     Can update events one by one only.
  
  @author Leman Chung
  @version 2.0
 */
public class AdminListUpdates extends AdminServlet 
{
    PrintWriter out;

        // get the template file name from a parameter
    private String templateFile = PEDefaults.ADMIN_UPDT_EVENTS;
    private String templateFooter = PEDefaults.FOOTER;
    private String templateBackToMenu = PEDefaults.BACK_TO_ADMIN_MENU;

    private void handleException(Exception e, String where)
      throws IOException
    {
        e.printStackTrace(System.err);
        System.err.println(e.getMessage());
        new PrintErrorMessage().printErrorAndClose(out, "ERROR at " + where + ": " + e.getMessage(), templateBackToMenu);
        return;
    }

  public void performAction(HttpServletRequest req, HttpServletResponse res)
         throws IOException {
    out = res.getWriter();
    ResultSet rs = null;
    SqlStatements sqlstmts = new SqlStatements ();
    PEParameter pep = new PEParameter(req);

    // 

    try {
        rs = sqlstmts.executeQuery(
          new PubEventsQueries().
	    adminListUpdatesQuery(new User(pep.getCreator())).toString());

    } catch (Exception e) {
	handleException(e, "executeQuery");
        return;
    }

    try {
    	if (!rs.next()) {
            // print out no event to delete error message.
            new PrintWebPage(PEDefaults.LOGOHEADER, out);
            out.println("<br><br><b>No events created by user " + pep.getCreator() + " existed!</b>");
            new PrintWebPage(templateBackToMenu, out);
            out.close();
            return;
    	} else {
            new PrintWebPage(templateFile, out); // print out header
            do {
                out.println("<tr><td><input type=\"radio\" name=\"" + PEParameter.EVENT_ID + "\" value=\"" + rs.getString(Fields.EEVENT_ID.getName()) + "\"></td>");
                out.println("<td>" + rs.getDate(Fields.ESTARTDATE.getName()) + "</td>");
                out.println("<td>" + rs.getDate(Fields.EENDDATE.getName()) + "</td>");
                out.println("<td>" + rs.getString(Fields.ESHORTDESC.getName()) + "<br>");
                out.println("(entered by: " + rs.getString(Fields.ECREATOR.getName()) + ")</td>");
                out.print("<td>" + Fields.getEventLongdesc(rs));
                out.println("</td></tr>");
            } while (rs.next());
            out.println("<tr><td></td><td></td><td></td><td></td></tr>");
            out.println("<tr><td></td><td></td>");
            out.println("<td><input type=\"submit\" value=\"Submit\"></td>");
            out.println("<td><input type=\"reset\" value=\"Clear\"></td>");
            out.println("<td></td></tr>");
    	}
    } catch (Exception e) {
	handleException(e, "printResult");
        return;
    } finally {
      sqlstmts.close();
    }
    out.println("</TABLE>\n</FORM>");
    new PrintWebPage(templateFooter, out);
    out.close();
  }
} // the end.
