package pubevents.updtevents;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import java.io.IOException;
import java.io.PrintWriter;
import java.sql.ResultSet;
import java.sql.SQLException;

import edu.washington.cac.calendar.CalParameter;
import edu.washington.cac.calendar.data.CaldataException;
import edu.washington.cac.calendar.data.Keyword;
import edu.washington.cac.calendar.data.NoSuchItemException;
import edu.washington.cac.calendar.db.DBResources;
import edu.washington.cac.calendar.db.Fields;

import pubevents.PEDefaults;
import pubevents.PEParameter;
import pubevents.addevents.SqlStatements;
import pubevents.delevents.AdminDelEvents;
import pubevents.util.DataUtil;
import pubevents.util.PrintWebPage;

/** UpdateEvents: update an existing event.
  
  @author Leman Chung
  @version 1.2
 */
public class UpdateEvents 
{
  /**
    update an event
    @param req HTTP request object
    @param res HTTP response object
    @param uid User doing the update
    @param uptype type of event (admin or not)
    @exception CaldataException if there's a problem with the form parameters
    @exception IOException if there's a problem writing the result
    @exception NoSuchItemException if the form references a keyword that 
        doesn't exist
    @exception SQLException if there's a problem with the database
   */
  public UpdateEvents(HttpServletRequest req, 
                      HttpServletResponse res, 
                      String uid, 
                      String uptype)
      throws CaldataException, IOException, NoSuchItemException, SQLException 
  {
    res.setContentType("text/html");
    PrintWriter out = res.getWriter();
    SqlStatements sqlstmts = new SqlStatements();
    PEParameter pep = new PEParameter(req);

    try {     
      int sponsorid;
      int locationid;
      int eventid;

      // get sponsorid, either by finding old sponsorid, or creating a
      // new sponsor.
      ResultSet rs = sqlstmts.selectSponsors(req);

      if (rs.next()) {
        sponsorid = rs.getInt(Fields.SSPONSOR_ID.getName());
      } else {
        sponsorid = sqlstmts.addSponsors(req, uid);
      }

      // get locationid, either by finding old locationid, or creating a
      // new location and getting its id
      rs = sqlstmts.selectLocations(req);

      if (rs.next()) {
        locationid = rs.getInt(Fields.LLOCATION_ID.getName());
      } else {
        locationid = sqlstmts.addLocations(req, uid);
      }

      // update the event
      sqlstmts.updateEvents(req, locationid, sponsorid);
  
      // If keyword changed, change event_keywords entry
      if (!pep.getWord().equals(pep.getHiddenKeyword())) {
        Keyword k = DataUtil.getKeyword(pep);
      
        eventid = pep.getEventID();
      
        // delete old event_keywords first.
        sqlstmts.deleteEventKeywords(eventid);
      
        // create new event_keywords entry
        sqlstmts.addEventKeywords(eventid, k.getId());
      }
  
      // compare new locationid, sponsorid with original
      // ids to determine whether to delete the old one or not.
      int orig_locationid = pep.getLocationID();
      int orig_sponsorid = pep.getSponsorID();
  
      if (orig_locationid != locationid) {
        // check to see if this location is still existed in events table
        // otherwise delete it.
        rs = sqlstmts.selectLocFromEvents(orig_locationid);
  
        if (!rs.next()) {
          if (orig_locationid > 2) {
            sqlstmts.executeUpdate(
                AdminDelEvents.deleteLocation(orig_locationid, uid));
          }
        }
      }
  
      if (orig_sponsorid != sponsorid) {
        rs = sqlstmts.selectSponsorFromEvents(orig_sponsorid);
          
        if (!rs.next()) {
          if (orig_sponsorid > 2) {
            sqlstmts.executeUpdate(
                AdminDelEvents.deleteSponsor(orig_sponsorid, uid));
          }
        }
      }
    } finally {
      sqlstmts.close();
    }
  
    // print out event updated message.

    if (uptype.equals(PEDefaults.ADMIN_UPDATE_FUNCTION)) {
      new PrintWebPage(PEDefaults.ADMIN_EVENT_UPDATED, out);
    } else {
      new PrintWebPage(PEDefaults.EVENT_UPDATED, out);
    }

    out.close();
  }
}
