package uwcal;

import java.io.IOException;

import javax.servlet.ServletConfig;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import edu.washington.cac.calendar.CalLogFactory;
import edu.washington.cac.calendar.data.User;
import edu.washington.cac.myuw.servlet.Log;
import edu.washington.cac.myuw.servlet.ServletSupport;
import edu.washington.cac.myuw.servlet.UWServlet;
import edu.washington.cac.myuw.servlet.session.InvalidSession;

import uwcal.out.CalMessageMaker;
import uwcal.out.WebResources;

/** The Base class of all UWCal servlets that log in. 

   @version 1.0
   @author Greg Barnes
*/
public abstract class CalLoginServlet extends CalServlet
{
  protected abstract String getName();
  protected abstract User getUser(HttpServletRequest req);
  protected abstract void startSession(CalSession session, Log log, User user)
      throws Exception;

  public void init(ServletConfig conf)
      throws ServletException
  {
    super.init(conf);
    createLog().println("Starting " + getName() + " servlet");
  }

  protected String getRedirectUrl(HttpServletRequest req)
  {
    if (req.getQueryString() == null ||
        req.getQueryString().trim().length() == 0) 
    {
        return WebResources.BASE_POST_URL;
    } else {
      return WebResources.BASE_NOPARAM_URL + req.getQueryString();
    }
  }

  protected boolean forceHttps() 
  {
    return true;                // default
  }

  protected void sendRedirect(HttpServletRequest req,
                              HttpServletResponse resp,
                              String url)
      throws IOException
  {
    UWServlet.sendRedirect(req, resp, url, forceHttps(), false);
  }

  /**
    Send Http response
    @param req Http request object
    @param resp Http response object
    @param user Name of the user
    @param session The current session
    @exception IOException If there's trouble writing the response
    @exception Exception If there's trouble doing something else
   */
  protected void sendResponse(HttpServletRequest req, 
                              HttpServletResponse resp,
                              User user,
                              CalSession session)
      throws IOException, Exception
  {
    sendRedirect(req, resp, getRedirectUrl(req));
  }

  /**
    Handle an HTTP GET request
    @param req The HTTP request object
    @param res The HTTP response object
    @exception ServletException If there's a problem with the servlet end
    @exception IOException If there's a problem writing the response
   */
  public void doGet(HttpServletRequest req, HttpServletResponse res)
    throws ServletException, IOException
  {
    User user = getUser(req);

    if (user == null) {
      createLog().println("CalLoginServlet::doGet getUser() returns null!");
      sendRedirect(req, res, WebResources.WELCOME_URL, false);
    } else {
      ServletSupport ss = new CalServletSupport(getName());
      Log log = new CalLogFactory().create(user.getNameApp());
      ss.setLog(log);

      try {
        user.logon();
        CalSession session = new CalSession(req);
        startSession(session, log, user);
        session.setUser(user);
        sendResponse(req, res, user, session);
      } catch (InvalidSession e){
        log.println(id + ": " + e);
        new CalMessageMaker().sessionErrorMessage(res);
      } catch (Throwable e){
        ss.handleException(e, res);
      } finally {
        ss.done();
      }
    }
  }
}
