// java

package uwcal;

import java.io.IOException;

import javax.servlet.http.HttpServletResponse;

import edu.washington.cac.myuw.servlet.Log;

import edu.washington.cac.calendar.CalParameter;
import edu.washington.cac.calendar.MyCalendar;
import edu.washington.cac.calendar.data.CaldataException;
import edu.washington.cac.calendar.data.EventsI;
import edu.washington.cac.calendar.data.ItemException;
import edu.washington.cac.calendar.data.User;

import uwcal.out.Page;

/**
  An illegal action/function in the application
  @author Greg Barnes
  @version 1.2
 */
public class IllegalAction extends CalAction 
{
  /**
    Create a minimal IllegalAction, not suitable for performing actions.
    This object can be used to match function names with the proper 
    IllegalAction class, and calling newInstance to create a more complete 
    version of the object which can perform the action

    @param function Name of the function this IllegalAction can handle
   */
  IllegalAction(String function) {
    super(function);
  }

  /** Create a new IllegalAction to perform actions

    @param function The function that was called
    @param cal The day for the action
    @param user The user performing the action
    @param es The EventsI object for the user
    @param cp The form parameters
    @param log A file to print messages to
   */
  IllegalAction(String function,       
                MyCalendar cal,
                User user, 
                EventsI es,
                CalParameter cp,
                Log log)
  {
    super(function, cal, user, es, cp, log);
  }

  /** @return a new IllegalAction
    @param cal The date in question
    @param user The user performing the action
    @param es The events for the user
    @param cp Form parameters
    @param log A file to print messages to
   */
  CalAction newInstance(MyCalendar cal, 
                        User user, 
                        EventsI es, 
                        CalParameter cp,
                        Log log) 
  {
    return new IllegalAction(getHandlesFunction(), cal, user, es, cp, log);
  }

  /** Print an error message
   */
  protected void basePerformAction() {        
    getLog().println("IllegalAction: " + getHandlesFunction());
  }

  /**
    Print the page to the servlet's output stream
    @param resp The servlet's response object
    @exception IOException if there's a problem printing the page
    @exception java.sql.SQLException if there's a problem with the database
    @exception CaldataException if the database contains bad data
   */
  protected void baseGeneratePage(HttpServletResponse resp) 
    throws IOException, java.sql.SQLException, CaldataException
  {
    try {
      // go to default view
      Page.create(CalParameter.DEFAULT_VIEW, cal, this.user, es, 
                  message, cp).print(resp);
    } catch (ItemException e) {
      throw new RuntimeException(
        "creating dayview shouldn't cause ItemException, but it did");
    }
  }
}
