package uwcal.out;

import org.apache.ecs.Element;
import org.apache.ecs.ElementContainer;
import org.apache.ecs.Entities;
import org.apache.ecs.html.IMG;

import edu.washington.cac.calendar.CalParameter;
import edu.washington.cac.calendar.MyCalendar;
import edu.washington.cac.calendar.data.Event;

/**
 * Generates various add event ref html (link, legend, etc).
 *
 * @author slh, Greg Barnes
 * @version 1.0
 */
public class AddEventRef  
{
  /** @return HTML for the 'add this event to my calendar' icon
   */
  private static IMG iconImage()
  {
    return new IMG(WebResources.ADD_TO_CALENDAR_URL).
               setAlt(DisplayText.ADD_TO_CALENDAR_ALT).setBorder(0);
  }

  /** 
    @return the URL for the 'add this event to my calendar' function
    @param eventid ID# of the event
    @param startdate Start date of the event, in form YYYYMMDD
   */
  private String iconLink(int eventid, String startdate)
  {
    return WebResources.BASE_ABSOLUTE_GET_PATH + 
           CalParameter.ADDEVENTREF_FUNC + 
           Util.DATE_PARAM + startdate + Util.EVENT_ID_PARAM + eventid;
  }

  /** 
    Get the URL for the 'add this event to my calendar' function
    @param e event in question
    @return the URL for the 'add this event to my calendar' function
   */
  private String iconLink(Event e)
  {
    return iconLink(e.getId(), e.startCalendar().getDateDigits());
  }

  /** 
    Get HTML for an 'add this event to my calendar' icon
    @param eventid ID# of the event
    @param startdate Start date of the event, in form YYYYMMDD
    @return HTML for an 'add this event to my calendar' icon
   */
  public Element icon(int eventid, String startdate)
  {
    return Util.linkItem(iconLink(eventid, startdate), iconImage());
  }

  /** 
    @return HTML for an 'add this event to my calendar' icon
    @param e The event in question
   */
  protected Element icon(Event e)
  {
    if (e.isPublic()) {
      return Util.linkItem(iconLink(e), iconImage());
    } else {
      return new ElementContainer();
    }
  }

  /**
    Get HTML for an icon plus a line of explanation
    @param e Event in question
    @return HTML for this line
   */
  Element addLine(Event e) 
  {
    return new ElementContainer().addElement(icon(e)).addElement(Entities.NBSP).
        addElement(Util.linkItem(iconLink(e), DisplayText.ADD_TO_CALENDAR_ALT));
  }

  /**
    Get HTML for an explanation of the icon
    @return HTML for an explanation of the icon
   */
  static Element iconLegend() 
  {
    return new ElementContainer().addElement(iconImage()).
                                  addElement(DisplayText.ADD_ICON_LEGEND);
  }

  /** Test the class
    @param args ignored
   */
  public static void main(String args[])
  {
    System.out.println(new AddEventRef().icon(17, "20020510").toString());
    System.out.println(AddEventRef.iconLegend().toString());
  }
}
