// java

package uwcal.out;

import java.text.DateFormat;

import org.apache.ecs.Element;
import org.apache.ecs.ElementContainer;
import org.apache.ecs.Entities;
import org.apache.ecs.html.BR;
import org.apache.ecs.html.Span;
import org.apache.ecs.html.TD;

import edu.washington.cac.calendar.MyCalendar;
import edu.washington.cac.calendar.data.Event;
import edu.washington.cac.calendar.data.EventsI;
import edu.washington.cac.calendar.data.User;

/**
  An object that prints events that appear in a list of many days' events
  @author Greg Barnes
  @version 1.0
 */
public class MultidayEventPrinter extends SimpleEventPrinter 
{
  /**
    Create a new instance
    @param user User for whom the events are printed
    @param today The current day
    @param view View this printer is a part of
   */
  protected MultidayEventPrinter(User user, 
                                 MyCalendar today, 
                                 Timeview view) 
  {
    super(user, today, view);
  }

  protected String linkStyle() 
  {
    return Style.LINK_ITEM;
  }

  protected String descStyle() 
  {
    return Style.WEEK_DESC;
  }

  protected String spanStyle() 
  {
    return Style.DAY_ITEM;
  }

  protected Element eventPrefix() 
  {
    return new ElementContainer();
  }

  /**
    Get the spacing between events
    @return the spacing between events
   */
  protected Element eventSpacing() 
  {
    return new ElementContainer();
  }

  /**
    Should the end date for an event be printed?
    @param e Event
    @return Should the end date for an event be printed?
   */
  private boolean shouldPrintEndDate(Event e)
  {
    return !e.startCalendar().isSameDay(e.endCalendar());
  }

  /**
    What to put between a date and a time
    @return What to put between a date and a time
   */
  protected String dateTimeSeparator()
  {
    return ", ";
  }

  /**
    Should the start date of an event be printed?
    @param e The event
    @return Should the start date of an event be printed?
   */
  private boolean shouldPrintStartDate(Event e)
  {
    return !e.startCalendar().isSameDay(this.today);
  }

  /**
    Is something printed for the timeRange of an event?
    @param e Event
    @return Is something printed for the timeRange of an event?
   */
  private boolean timeRangePrintsSomething(Event e)
  {
    return e.startCalendar().hasTime() || shouldPrintStartDate(e) ||
           e.endCalendar().hasTime() || shouldPrintEndDate(e);
  }

  /**
    Get the date/time info for the event
    @param e The event
    @return the date/time info for the event
   */
  protected Element timeRange(Event e) 
  {
    if (!timeRangePrintsSomething(e)) {
      return new ElementContainer();
    }

    ElementContainer ec = new ElementContainer().
        addElement(dateTime(e.startCalendar(), 
                            shouldPrintStartDate(e),
                            DateFormat.FULL));

    if (e.endCalendar().hasTime() || shouldPrintEndDate(e)) {
      ec.addElement(" - ").addElement(dateTime(e.endCalendar(), 
                                      shouldPrintEndDate(e), 
                                      DateFormat.FULL));
    }

    return new ElementContainer().addElement(Util.spanItem(ec, timeStyle())).
           addElement(new BR()).addElement("\n");
  }     

  /** 
    Get the More/Edit/Delete links (or the equivalent) for an event
    @param e Event in question
    @return the More/Edit/Delete links (or the equivalent) for an event
   */
  private Element moreEditDelete(Event e) 
  {
    return new Span().addElement(
        new MoreEditDelete(
            new EventHelperPrinter(e, this.view), this.today, this.user).
            print()).
        addElement("\n").
        setClass(Style.AUX);
  }

  /**
    Get HTML for a single event
    @param e The event
    @param es The cache of all events
    @return HTML for a single event
   */
  protected Element format(Event e, EventsI es)
  {
    return new TD().addElement("\n").
           addElement(eventPrefix()).addElement("\n ").
           addElement(timeRange(e)).addElement("\n ").
           addElement(Entities.NBSP).
           addElement(new Span().
                      addElement(addIcon(e)).
                      addElement(eventDesc(e)).
                      addElement(location(e, es)).addElement("\n").
                      setClass(descStyle())).
           addElement(eventSpacing()).addElement("\n").
           addElement(Entities.NBSP).
           addElement(moreEditDelete(e)).
           setClass(Style.LIST_CELL);
  }
}
