// java

package uwcal.out;

import org.apache.ecs.Element;
import org.apache.ecs.ElementContainer;
import org.apache.ecs.Entities;
import org.apache.ecs.html.Span;

import edu.washington.cac.calendar.MyCalendar;
import edu.washington.cac.calendar.data.Event;
import edu.washington.cac.calendar.data.EventsI;
import edu.washington.cac.calendar.data.User;

/**
  An object that prints the basics about an event.  This 
  often means the event appears in a many-day view, where space is
  at a premium.

  @author Greg Barnes
  @version 1.2
 */
public abstract class SimpleEventPrinter extends EventPrinter 
{
  /**
    Create a new instance
    @param user User for whom events will be printed
    @param today The current day
    @param view View this printer is a part of
   */
  protected SimpleEventPrinter(User user,
                               MyCalendar today, 
                               Timeview view)
  {
    super(user, today, view);
  }

  protected abstract Element eventPrefix();
  protected abstract Element eventSpacing();
  protected abstract String descStyle();

  protected String noTimeRange() 
  {
    return "";
  }

  /**
    Get the event formatted in HTML
    @param e The event
    @param es Cache of events
    @return the formatted event
   */
  protected Element format(Event e, EventsI es) 
  {
    return new ElementContainer().addElement("\n").
           addElement(eventPrefix()).addElement("\n ").
           addElement(timeRange(e)).addElement("\n ").
           addElement(hasNoTime(e) ? "" : Entities.NBSP).
           addElement(new Span().
                      addElement(addIcon(e)).
                      addElement(eventDesc(e)).
                      addElement(location(e, es)).addElement("\n").
                      setClass(descStyle())).
           addElement(eventSpacing()).addElement("\n");
  }
}
