// java

package uwcal.out.forms;

import java.text.DateFormat;
import java.util.Calendar;
import java.util.Date;

import org.apache.ecs.*;
import org.apache.ecs.html.*;

import edu.washington.cac.calendar.MyCalendar;
import uwcal.out.forms.*;

  /** A month/day/year selection form
    @author Greg Barnes
    @version 1.0
   */

public class DateInputs {
    private MyCalendar mc;
    private String monthInputName;
    private String dayInputName;
    private String yearInputName;
    private Date initialValue;
    private SameWidget sw;

    DateInputs(MyCalendar mc, 
		String monthInputName, 
		String dayInputName,
		String yearInputName,
		Date initialValue,
		SameWidget sw) 
    {
	this.mc = mc;
	this.monthInputName = monthInputName;
	this.dayInputName = dayInputName;
	this.yearInputName = yearInputName;
	this.initialValue = initialValue;
	this.sw = sw;
    }

    private int monthSelected(Date d) {
	MyCalendar selected = (d == null) ? mc : new MyCalendar(d);
	return selected.get(Calendar.MONTH);
    }

    private Option[] monthOptions() {
        MyCalendar currentMonth = new MyCalendar(
	  new MyCalendar().firstMonthOfThisYear());
        Option[] o = new Option[currentMonth.monthsInYear()];
	int i;

        for (i = 0; i < o.length;
          i++, currentMonth = currentMonth.addTime(Calendar.MONTH, 1))
	{
	    o[i] = new Option(currentMonth.twoDigitMonth());
	    o[i].addElement(currentMonth.getComponent(DateFormat.MONTH_FIELD, 
	      DateFormat.MEDIUM));
	}

	if (!sw.sameMonth()) {
	    o[monthSelected(initialValue)].setSelected(true);
	}

	return o;
    }
        
    private int daySelected(Date d) {
	MyCalendar selected = (d == null) ? mc : new MyCalendar(d);
	  // day #n corresponds to the option #(n-1)
	return selected.get(Calendar.DAY_OF_MONTH) - 1;
    }

    private Option[] dayOptions() {
        MyCalendar mc = new MyCalendar();
        Option[] o = new Option[mc.getMaximum(Calendar.DAY_OF_MONTH)];
	int i;

        for (i = 0; i < o.length; i++) {
	      // option #n corresponds to day #(n+1)
	    o[i] = new Option(mc.twoDigit(i+1));
	    o[i].addElement((i+1) + "");  
	}

	if (!sw.sameDay()) {
	    o[daySelected(initialValue)].setSelected(true);
	}

	return o;
    }

    private static final int YEAR_LENGTH = 4;

    protected static Element yearInput(String name, String year) 
    {
        return new Input(Input.TEXT, name, year).setSize(YEAR_LENGTH).
	  setMaxlength(YEAR_LENGTH);
    }

    protected Element year()
    {
	if (sw.sameYear()) {
            return yearInput(yearInputName, FormsDisplayText.SAME);
	} 

	MyCalendar selected = (initialValue == null) ? mc :
	  new MyCalendar(initialValue);

        return yearInput(yearInputName, selected.fourDigitYear());
    }

    private Select initialSelect(String name, boolean useSame, 
      boolean selectSame) 
    {
	Select s = new Select(name);

	if (useSame) {
	    Option o = new Option(FormsDisplayText.SAME).
	      addElement(FormsDisplayText.SAME);
	
	    if (selectSame) {
		o.setSelected(true);
	    }

	    s.addElement(o);
	}

	return s;
    }

    private Element dateSelects() {
        return new ElementContainer().
          addElement(initialSelect(monthInputName, sw.useSame(), 
	    sw.sameMonth()).
	    addElement(monthOptions())).
          addElement(initialSelect(dayInputName, sw.useSame(), sw.sameDay()).
            addElement(dayOptions())).
          addElement(year());
    }

    public Span getInputs()
    {
	return new Span().addElement(dateSelects());
    }
}
