// java

package uwcal.out.forms;

import org.apache.ecs.Element;
import org.apache.ecs.ElementContainer;
import org.apache.ecs.Entities;
import org.apache.ecs.StringElement;

import edu.washington.cac.calendar.CalLogFactory;
import edu.washington.cac.calendar.CalParameter;
import edu.washington.cac.calendar.MyCalendar;
import edu.washington.cac.calendar.data.Event;
import edu.washington.cac.calendar.data.Locations;
import edu.washington.cac.calendar.data.User;
import edu.washington.cac.myuw.util.Coder;

import uwcal.out.Page;

/**
  A form to edit an event
  @author Greg Barnes
  @version 1.0
 */
public class EditEventForm extends EventForm 
{
  /** Create a new instance
    @param page Page this form is a part of
    @param e The event to be edited
    @param ls The event's locations
   */
  public EditEventForm(Page page,
                       Event e, 
                       Locations ls)
  {
    super(page, e, ls);
  }

  protected String formFunction() {
      return CalParameter.REPLACEEVENT_FUNC;
  }

  /**
    Get the hidden tags for this form
    @return the hidden tags for this form
   */
  protected ElementContainer hiddens() 
  {
    return super.hiddens().
           addElement(hidden(CalParameter.EVENT_ID, this.e.getId())).
           addElement("\n");
  }

  protected String titleText() 
  {
    return FormsDisplayText.EDIT_EVENT_TITLE;
  }

  protected Element oldTime(String timeString) 
  {
    if (timeString.trim().length() == 0) {
      return new ElementContainer().addElement(Entities.NBSP).
                                    addElement(FormsDisplayText.NO_TIME);
    } else {
      return new StringElement(FormsDisplayText.AT + " " + timeString);
    }
  }

  protected Element oldStartTime() {
      return oldTime(this.e.getStarttimeString());
  }

  protected Element newStartTime() {
      return startHourInput(this.e.getStarttime());
  }

  protected Element oldEndTime() {
      return oldTime(this.e.getEndtimeString());
  }

  protected Element newEndTime() {
      return endHourInput(this.e.getEndtime());
  }

  protected Element location() {
      return CommonFormElements.oldNewInput(
        FormsDisplayText.EDIT_OLD_LOCATION,
        new StringElement(
            Coder.HTMLencode(this.e.getLocation(this.ls).toString())),
        FormsDisplayText.EDIT_NEW_LOCATION, 
        locationInput(this.e.getLocationid()));
  }

  protected Element oldStartDate() {
      return dateValue(this.e.startCalendar());
  }

  protected Element newStartDate() {
    return startDateInput(this.e.getStartdate());
  }

  protected Element oldEndDate() {
    return dateValue(this.e.endCalendar());
  }

  protected Element newEndDate() {
      return endDateInput(this.e.getEnddate(), this.e.getStartdate());
  }

  protected Element dateTime(String oldTitle, 
                              String newTitle,
                              Element oldDate,
                              Element oldTime,
                              Element newDate, 
                              Element newTime) 
  {
      return new ElementContainer().
        addElement(CommonFormElements.centeredBoldText(oldTitle)).
        addElement(CommonFormElements.tableRowTwoCells(oldDate, oldTime)).
        addElement(CommonFormElements.centeredBoldText(newTitle)).
        addElement(CommonFormElements.tableRowTwoCells(newDate, newTime));
  }

  protected Element dateTimeHeader() {
      return new ElementContainer();
  }

  protected Element dateTimeDivider() {
      return new ElementContainer();
  }

  protected Element startDateTime() {
      return dateTime(FormsDisplayText.EDIT_OLD_STARTDATETIME,
        FormsDisplayText.EDIT_NEW_STARTDATETIME, oldStartDate(), 
        oldStartTime(), newStartDate(), newStartTime());
  }

  protected Element endDateTime() {
      return dateTime(FormsDisplayText.EDIT_OLD_ENDDATETIME,
        FormsDisplayText.EDIT_NEW_ENDDATETIME, oldEndDate(), 
        oldEndTime(), newEndDate(), newEndTime());
  }

  protected String submitButtonText() {
        return FormsDisplayText.CHANGE_EVENT;
  }
}
