// java

package uwcal.schedule;

import javax.servlet.ServletOutputStream;
import javax.servlet.http.HttpServletResponse;

import org.apache.ecs.Element;
import org.apache.ecs.ElementContainer;
import org.apache.ecs.html.Table;
import org.apache.ecs.html.TR;

import edu.washington.cac.calendar.data.User;

import uwcal.out.DateHeader;
import uwcal.out.Message;
import uwcal.out.Page;
import uwcal.out.Style;

/**
  An page output after a person's schedule is added 
  @author Greg Barnes
  @version 1.0
 */
public class AddSchedulePage extends Page
{
  /** Type of the schedule */
  private char scheduleType;

  /**
    Create a new instance
    @param user User we're adding the schedule for
    @param scheduleName Name of the schedule
   */
  protected AddSchedulePage(User user, char scheduleType) 
  {
    super(null, user, null);
    this.scheduleType = scheduleType;
  }

  /** 
    Get the main part of the page as HTML
    @return the main part of the page as HTML
   */
  protected Element contents() 
  {
    return new Table().
           setCellSpacing(20).addElement("\n").
           addElement(new TR().
               addElement(new Message(
                   ScheduleText.scheduleMessage(this.scheduleType).toString()).
               asTableCell())).
           setID(Style.SMALL_BODY_TABLE);
  }

  /**
    Get the title of this page
    @return the title of this page
   */
  protected String title()
  {
    return ScheduleText.ADD_SCHEDULE_TITLE;
  }

  /**
    Always return null
    @return null
   */
  protected DateHeader getDateHeader() 
  {
    return null;
  }

  /**
    Always return null
    @return null
   */
  public String nextFunction()
  {
    return null;
  }

  /**
    Should we see the middle row of links in the header?
    @return false
   */
  protected boolean shouldShowButtonRow()
  {
    return false;
  }

  /**
    Should we see the tool row in the header?
    @return false
   */
  protected boolean shouldShowToolRow()
  {
    return false;
  }

  /**
    Get the legend at the bottom.
    @return nothing
    */
  protected Element legend()
  {
    return new ElementContainer();
  }
}
